@@ -6,7 +6,11 @@ Before using other language you must set
 import os
 
 LANGUAGE = os.environ.get("SELENIUM-ODOO-PAGE-LANGUAGE", "en")
-TERMS = {"Create and Edit...": "Créer et modifier..."}
+TERMS = {
+    "Create and Edit...": "Créer et modifier...",
+    "Create Invoice": "Créer une facture",
+    "Confirm": "Confirmer",
+}
 
 
 def get_term(label):
